cli

package
v0.17.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 14, 2026 License: MIT Imports: 43 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute() int

func WriteJUnitReport

func WriteJUnitReport(path string, results []artifacts.RunResult) error

WriteJUnitReport renders the JUnit XML for the given run results and writes it to `path`. The file's parent directory is created if it does not exist. Returns an error if the file cannot be written.

Types

This section is empty.

Jump to